==> jc-1.4.0.tar.gz: javax/swing/event/AncestorEvent.h <==
// public class javax.swing.event.AncestorEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class d5bc69ad1efa0e0b javax_swing_event_AncestorEvent

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_javax_swing_event_AncestorEvent_H_
#define _JC_javax_swing_event_AncestorEvent_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_event_AncestorEvent$sub_refs	_jc_javax_swing_event_AncestorEvent$sub_refs;
typedef struct _jc_javax_swing_event_AncestorEvent$sub_nonrefs	_jc_javax_swing_event_AncestorEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_AncestorEvent$refs	_jc_javax_swing_event_AncestorEvent$refs;
typedef struct _jc_javax_swing_event_AncestorEvent$nonrefs	_jc_javax_swing_event_AncestorEvent$nonrefs;
typedef struct _jc_javax_swing_event_AncestorEvent$object	_jc_javax_swing_event_AncestorEvent$object;

typedef struct _jc_javax_swing_event_AncestorEvent$fields_struct	_jc_javax_swing_event_AncestorEvent$fields_struct;
typedef const struct _jc_javax_swing_event_AncestorEvent$vmethods	_jc_javax_swing_event_AncestorEvent$vmethods;
typedef const struct _jc_javax_swing_event_AncestorEvent$vtable	_jc_javax_swing_event_AncestorEvent$vtable;
typedef const struct _jc_javax_swing_event_AncestorEvent$vtype	_jc_javax_swing_event_AncestorEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_AncestorEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ANCESTOR__5fADDED;
	jint	ANCESTOR__5fMOVED;
	jint	ANCESTOR__5fREMOVED;
};
extern _jc_javax_swing_event_AncestorEvent$fields_struct _jc_javax_swing_event_AncestorEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_AncestorEvent$method$_init$a653caa3c77bdedf(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *, struct _jc_javax_swing_JComponent$object *, jint, struct _jc_java_awt_Container$object *, struct _jc_java_awt_Container$object *);

// Virtual methods
extern struct _jc_java_awt_Container$object *_jc_javax_swing_event_AncestorEvent$method$getAncestor$0e522941b2288432(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *);
extern struct _jc_java_awt_Container$object *_jc_javax_swing_event_AncestorEvent$method$getAncestorParent$1c579a54e479c8dd(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *);
extern struct _jc_javax_swing_JComponent$object *_jc_javax_swing_event_AncestorEvent$method$getComponent$b174a2e555173362(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_AncestorEvent$method_info$getAncestor$0e522941b2288432;
extern _jc_method _jc_javax_swing_event_AncestorEvent$method_info$getAncestorParent$1c579a54e479c8dd;
extern _jc_method _jc_javax_swing_event_AncestorEvent$method_info$getComponent$b174a2e555173362;

// Virtual methods structure
struct _jc_javax_swing_event_AncestorEvent$vmethods {
	struct _jc_java_awt_Container$object	*(*getAncestor$0e522941b2288432)(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *);
	struct _jc_java_awt_Container$object	*(*getAncestorParent$1c579a54e479c8dd)(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *);
	struct _jc_javax_swing_JComponent$object	*(*getComponent$b174a2e555173362)(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_AncestorEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_javax_swing_event_AncestorEvent$vmethods	javax_swing_event_AncestorEvent;
};

// Vtype
struct _jc_javax_swing_event_AncestorEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_AncestorEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_AncestorEvent$sub_refs {
	struct _jc_javax_swing_JComponent$object	*sourceComponent;
	struct _jc_java_awt_Container$object	*ancestor;
	struct _jc_java_awt_Container$object	*ancestorParent;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_AncestorEvent$refs {
    _jc_javax_swing_event_AncestorEvent$sub_refs	javax_swing_event_AncestorEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_AncestorEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_AncestorEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_javax_swing_event_AncestorEvent$sub_nonrefs	javax_swing_event_AncestorEvent;
};

// Object instance structure
struct _jc_javax_swing_event_AncestorEvent$object {
	_jc_javax_swing_event_AncestorEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_AncestorEvent$vtype	*vtype;
	_jc_javax_swing_event_AncestorEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_AncestorEvent$vtype _jc_javax_swing_event_AncestorEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_AncestorEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_AncestorEvent$class_object;

#endif	/* _JC_javax_swing_event_AncestorEvent_H_ */

==> jc-1.4.5.tar.gz: javax/swing/event/AncestorEvent.h <==
// public class javax.swing.event.AncestorEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class d5bc69ad1efa0e0b javax_swing_event_AncestorEvent

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_javax_swing_event_AncestorEvent_H_
#define _JC_javax_swing_event_AncestorEvent_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_event_AncestorEvent$sub_refs	_jc_javax_swing_event_AncestorEvent$sub_refs;
typedef struct _jc_javax_swing_event_AncestorEvent$sub_nonrefs	_jc_javax_swing_event_AncestorEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_AncestorEvent$refs	_jc_javax_swing_event_AncestorEvent$refs;
typedef struct _jc_javax_swing_event_AncestorEvent$nonrefs	_jc_javax_swing_event_AncestorEvent$nonrefs;
typedef struct _jc_javax_swing_event_AncestorEvent$object	_jc_javax_swing_event_AncestorEvent$object;

typedef struct _jc_javax_swing_event_AncestorEvent$fields_struct	_jc_javax_swing_event_AncestorEvent$fields_struct;
typedef const struct _jc_javax_swing_event_AncestorEvent$vmethods	_jc_javax_swing_event_AncestorEvent$vmethods;
typedef const struct _jc_javax_swing_event_AncestorEvent$vtable	_jc_javax_swing_event_AncestorEvent$vtable;
typedef const struct _jc_javax_swing_event_AncestorEvent$vtype	_jc_javax_swing_event_AncestorEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_AncestorEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ANCESTOR__5fADDED;
	jint	ANCESTOR__5fMOVED;
	jint	ANCESTOR__5fREMOVED;
};
extern _jc_javax_swing_event_AncestorEvent$fields_struct _jc_javax_swing_event_AncestorEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_AncestorEvent$method$_init$a653caa3c77bdedf(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *, struct _jc_javax_swing_JComponent$object *, jint, struct _jc_java_awt_Container$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Container$object *_jc_javax_swing_event_AncestorEvent$method$getAncestor$0e522941b2288432(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Container$object *_jc_javax_swing_event_AncestorEvent$method$getAncestorParent$1c579a54e479c8dd(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_JComponent$object *_jc_javax_swing_event_AncestorEvent$method$getComponent$b174a2e555173362(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_AncestorEvent$method_info$getAncestor$0e522941b2288432;
extern _jc_method _jc_javax_swing_event_AncestorEvent$method_info$getAncestorParent$1c579a54e479c8dd;
extern _jc_method _jc_javax_swing_event_AncestorEvent$method_info$getComponent$b174a2e555173362;

// Virtual methods structure
struct _jc_javax_swing_event_AncestorEvent$vmethods {
	struct _jc_java_awt_Container$object	*(*getAncestor$0e522941b2288432)(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Container$object	*(*getAncestorParent$1c579a54e479c8dd)(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_JComponent$object	*(*getComponent$b174a2e555173362)(_jc_env *, struct _jc_javax_swing_event_AncestorEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_AncestorEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_javax_swing_event_AncestorEvent$vmethods	javax_swing_event_AncestorEvent;
};

// Vtype
struct _jc_javax_swing_event_AncestorEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_AncestorEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_AncestorEvent$sub_refs {
	struct _jc_javax_swing_JComponent$object	*sourceComponent;
	struct _jc_java_awt_Container$object	*ancestor;
	struct _jc_java_awt_Container$object	*ancestorParent;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_AncestorEvent$refs {
    _jc_javax_swing_event_AncestorEvent$sub_refs	javax_swing_event_AncestorEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_AncestorEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_AncestorEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_javax_swing_event_AncestorEvent$sub_nonrefs	javax_swing_event_AncestorEvent;
};

// Object instance structure
struct _jc_javax_swing_event_AncestorEvent$object {
	_jc_javax_swing_event_AncestorEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_AncestorEvent$vtype	*vtype;
	_jc_javax_swing_event_AncestorEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_AncestorEvent$vtype _jc_javax_swing_event_AncestorEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_AncestorEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_AncestorEvent$class_object;

#endif	/* _JC_javax_swing_event_AncestorEvent_H_ */
